@@ -56,6 +56,8 @@ import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.client.onboarding.json.actions.AllScenariosAction;
 import com.openexchange.client.onboarding.json.actions.ConfigAction;
 import com.openexchange.client.onboarding.json.actions.DevicesAction;
+import com.openexchange.client.onboarding.json.actions.DownloadAction;
+import com.openexchange.client.onboarding.json.actions.DownloadLinkAction;
 import com.openexchange.client.onboarding.json.actions.ExecuteAction;
 import com.openexchange.client.onboarding.json.actions.GetScenarioAction;
 import com.openexchange.exception.OXException;
@@ -84,6 +86,8 @@ public class OnboardingActionFactory implements AJAXActionServiceFactory {
         actions.put("get", new GetScenarioAction(services));
         actions.put("scenarios", new AllScenariosAction(services));
         actions.put("execute", new ExecuteAction(services));
+        actions.put("download", new DownloadAction(services));
+        actions.put("link", new DownloadLinkAction(services));
         this.actions = actions.build();
     }
 
