@@ -74,7 +74,6 @@ import com.openexchange.client.onboarding.plist.PlistResult;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.userconfiguration.Permission;
-import com.openexchange.i18n.tools.StringHelper;
 import com.openexchange.java.Strings;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.api.MailConfig;
@@ -358,6 +357,9 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
                     }
                 } else {
                     smtpLogin = transportSettings.getLogin();
+                    if (Strings.isEmpty(smtpLogin)) {
+                        smtpLogin = imapConfiguration.login;
+                    }
                 }
                 configBuilder.withLogin(smtpLogin);
             }
@@ -402,7 +404,7 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
 
                 @Override
                 public Set<Flag> flags() {
-                    return SessionMatcher.ALL_FLAGS;
+                    return SessionMatcher.ONLY_SHORT_TERM;
                 }
 
                 @Override
@@ -457,12 +459,12 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
         boolean needsAuthentication = configurations.smtpConfig.needsAuthentication;
         if (needsAuthentication) {
             configuration.put(SMTP_LOGIN_FIELD, configurations.smtpConfig.login);
-            configuration.put(SMTP_SERVER_FIELD, configurations.smtpConfig.host);
         } else {
-            String none = StringHelper.valueOf(getUser(session).getLocale()).getString("None");
-            configuration.put(SMTP_LOGIN_FIELD, none);
-            configuration.put(SMTP_SERVER_FIELD, none);
+            //String none = StringHelper.valueOf(getUser(session).getLocale()).getString("None");
+            //configuration.put(SMTP_LOGIN_FIELD, none);
+            configuration.put(SMTP_LOGIN_FIELD, configurations.smtpConfig.login);
         }
+        configuration.put(SMTP_SERVER_FIELD, configurations.smtpConfig.host);
         configuration.put(SMTP_PORT_FIELD, new Integer(configurations.smtpConfig.port));
         configuration.put(SMTP_SECURE_FIELD, new Boolean(configurations.smtpConfig.secure));
 
@@ -571,9 +573,9 @@ public class MailOnboardingProvider implements OnboardingPlistProvider {
 
         // Designates the user name for the email account, usually the same as the email address up to the @ character.
         // If not present in the payload, and the account is set up to require authentication for outgoing email, the device prompts for this string during profile installation.
-        if (needsAuthentication) {
-            payloadContent.addStringValue("OutgoingMailServerUsername", configurations.smtpConfig.login);
+        payloadContent.addStringValue("OutgoingMailServerUsername", configurations.smtpConfig.login);
 
+        if (needsAuthentication) {
             if (Strings.isNotEmpty(configurations.smtpConfig.password) && Strings.isNotEmpty(configurations.imapConfig.password) && configurations.smtpConfig.password.equals(configurations.imapConfig.password)) {
                 payloadContent.addBooleanValue("OutgoingPasswordSameAsIncomingPassword", true);
             }
