@@ -49,6 +49,7 @@
 
 package com.openexchange.client.onboarding;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -212,7 +213,7 @@ public class OnboardingUtility {
             transportProvider.createNewNoReplyTransport(contextId);
             return true;
         } catch (OXException e) {
-            LOG.debug("\"no reply\" transport is not available for context {}", contextId, e);
+            LOG.debug("\"no reply\" transport is not available for context {}", I(contextId), e);
             return false;
         }
     }
@@ -290,22 +291,7 @@ public class OnboardingUtility {
      */
     public static boolean isScenarioEnabled(String scenarioId, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        if (Strings.isEmpty(scenarioId)) {
-            return false;
-        }
-
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-        ComposedConfigProperty<String> property = view.property("com.openexchange.client.onboarding.enabledScenarios", String.class);
-        if (null == property || !property.isDefined()) {
-            // Nothing enabled...
-            return false;
-        }
-
-        String[] ids = Strings.splitByComma(Strings.asciiLowerCase(property.get()));
-        Set<String> set = new HashSet<String>(ids.length, 0.9F);
-        set.addAll(Arrays.asList(ids));
-        return set.contains(Strings.asciiLowerCase(scenarioId));
+        return isScenarioEnabled(scenarioId, session.getUserId(), session.getContextId());
     }
 
     /**
@@ -380,15 +366,7 @@ public class OnboardingUtility {
      */
     public static boolean getBoolValue(String propertyName, boolean defaultValue, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-
-        ComposedConfigProperty<Boolean> property = view.property(propertyName, boolean.class);
-        if (null == property || !property.isDefined()) {
-            return defaultValue;
-        }
-
-        return property.get().booleanValue();
+        return getBoolValue(propertyName, defaultValue, session.getUserId(), session.getContextId());
     }
 
     /**
@@ -477,19 +455,7 @@ public class OnboardingUtility {
      */
     public static String getTranslationFromProperty(String propertyName, String defaultValue, boolean translateDefaultValue, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-
-        ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
-            return translateDefaultValue ? StringHelper.valueOf(getLocaleFor(session)).getString(defaultValue) : defaultValue;
-        }
-
-        String i18nString = property.get();
-        if (Strings.isEmpty(i18nString)) {
-            return translateDefaultValue ? StringHelper.valueOf(getLocaleFor(session)).getString(defaultValue) : defaultValue;
-        }
-        return StringHelper.valueOf(getLocaleFor(session)).getString(i18nString);
+        return getTranslationFromProperty(propertyName, defaultValue, translateDefaultValue, session.getUserId(), session.getContextId());
     }
 
     /**
@@ -531,16 +497,7 @@ public class OnboardingUtility {
      */
     public static String getValueFromProperty(String propertyName, String defaultValue, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-
-        ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
-            return defaultValue;
-        }
-
-        String value = property.get();
-        return Strings.isEmpty(value) ? defaultValue : value;
+        return getValueFromProperty(propertyName, defaultValue, session.getUserId(), session.getContextId());
     }
 
     /**
@@ -578,20 +535,7 @@ public class OnboardingUtility {
      */
     public static Integer getIntFromProperty(String propertyName, Integer defaultValue, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-
-        ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
-            return defaultValue;
-        }
-
-        try {
-            String value = property.get();
-            return Strings.isEmpty(value) ? defaultValue : Integer.valueOf(value.trim());
-        } catch (NumberFormatException e) {
-            return defaultValue;
-        }
+        return getIntFromProperty(propertyName, defaultValue, session.getUserId(), session.getContextId());
     }
 
     /**
@@ -616,7 +560,7 @@ public class OnboardingUtility {
         try {
             String value = property.get();
             return Strings.isEmpty(value) ? defaultValue : Integer.valueOf(value.trim());
-        } catch (NumberFormatException e) {
+        } catch (@SuppressWarnings("unused") NumberFormatException e) {
             return defaultValue;
         }
     }
@@ -633,16 +577,7 @@ public class OnboardingUtility {
      */
     public static Boolean getBoolFromProperty(String propertyName, Boolean defaultValue, Session session) throws OXException {
         Validate.notNull(session, "session must not be null");
-        ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
-        ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
-
-        ComposedConfigProperty<String> property = view.property(propertyName, String.class);
-        if (null == property || !property.isDefined()) {
-            return defaultValue;
-        }
-
-        String value = property.get();
-        return Strings.isEmpty(value) ? defaultValue : ("true".equalsIgnoreCase(value.trim()) ? Boolean.TRUE : ("false".equalsIgnoreCase(value.trim()) ? Boolean.FALSE : defaultValue));
+        return getBoolFromProperty(propertyName, defaultValue,session.getUserId(), session.getContextId());
     }
 
     /**
@@ -741,7 +676,7 @@ public class OnboardingUtility {
             MimeTypeMap mimeTypeMap = Services.getService(MimeTypeMap.class);
             return new DefaultIcon(imageBytes, null == mimeTypeMap ? null : mimeTypeMap.getContentType(imageName));
         } catch (java.io.FileNotFoundException e) {
-            LOG.warn("Icon image {} does not exist in path {}.", imageName, templatesPath);
+            LOG.warn("Icon image {} does not exist in path {}.", imageName, templatesPath, e);
             return null;
         } catch (IOException e) {
             LOG.warn("Could not load icon image {} from path {}.", imageName, templatesPath, e);
@@ -891,7 +826,7 @@ public class OnboardingUtility {
         Map<String, String> attributes = userService.getUser(userId, contextId).getAttributes();
         String login = attributes.get("loginnamerecorder/user_login");
         if (null == login) {
-            LOG.warn("No login user attribute for user {} in context {}.", userId, contextId);
+            LOG.warn("No login user attribute for user {} in context {}.", I(userId), I(contextId));
             return null;
         }
         return login;
